@@ -66,7 +66,7 @@ class IRelatedItems(IPortletDataProvider):
         title=_(u'Portlet title'),
         description=_(u'Title in portlet.'),
         required=True,
-        default=u'Related Items'
+        default=_(u'Related Items')
     )
 
     count = schema.Int(
@@ -168,7 +168,7 @@ class Assignment(base.Assignment):
         """This property is used to give the title of the portlet in the
         "manage portlets" screen.
         """
-        return "Related Items"
+        return _(u"Related Items")
 
 class Renderer(base.Renderer):
     """Portlet renderer.
@@ -284,7 +284,7 @@ class Renderer(base.Renderer):
         # Filter out boolean searches and keywords with only one letter
         search_query = [res
                         for res in search_query
-                        if not res.lower() in ['not','and','or'] and len(res)!=1]
+			if not res.lower() in ['not','and','or'] and len(res)!=1]
 
         return search_query
 
